==> transformers_lightning-0.7.2.tar.gz: transformers_lightning-0.7.2/transformers_lightning/schedulers/constant_scheduler_with_warmup.py <==
from argparse import ArgumentParser, Namespace

import torch
from pytorch_lightning.utilities.warnings import rank_zero_warn

from transformers_lightning.schedulers.super_scheduler import SuperScheduler


class ConstantSchedulerWithWarmup(SuperScheduler):
    r"""
    Create a schedule with a learning rate that keeps a contant value
    but increases linearly for the first `num_warmup_steps`.
    More informations about the default parameters can be found on the documentation of
    `_LRScheduler` in the `torch` project.

    Args:
        hyperparameters: (:class:`~argparse.Namespace`):
            Collection of training hyperparameters.
        optimizer (:class:`~torch.optim.Optimizer`):
            The optimizer for which to schedule the learning rate.

    Args through CLI:
        num_warmup_steps (:obj:`int`):
            The number of steps for the warmup phase.
        last_epoch (:obj:`int`, `optional`, defaults to -1):
            The index of the last epoch when resuming training.
        verbose (bool): If ``True``, prints a message to stdout for
            each update. Default: ``False``.

    Example:
        >>> scheduler = ConstantSchedulerWithWarmup(hyperparameters, optimizer)
    """

    def __init__(self, hyperparameters: Namespace, optimizer: torch.optim.Optimizer):
        super().__init__(hyperparameters, optimizer)

        if not isinstance(hyperparameters.num_warmup_steps, int) or not hyperparameters.num_warmup_steps >= 0:
            raise ValueError("`num_warmup_steps` must be an integer greater than 0")

    def lr_lambda(self, current_step: int) -> int:
        """ Compute lambda that is going to scale the learning rate. """
        if current_step < self.hyperparameters.num_warmup_steps:
            return float(current_step) / float(max(1, self.hyperparameters.num_warmup_steps))
        return 1.0

    def get_lr(self):
        if not self._get_lr_called_within_step:
            rank_zero_warn("To get the last learning rate computed by the scheduler, " "please use `get_last_lr()`.")

        return [base_lr * self.lr_lambda(self.last_epoch) for base_lr in self.base_lrs]

    @staticmethod
    def add_scheduler_specific_args(parser: ArgumentParser):
        r""" Add here the hyperparameters specific of the scheduler like the number of warmup steps. """
        super(ConstantSchedulerWithWarmup, ConstantSchedulerWithWarmup).add_scheduler_specific_args(parser)
        parser.add_argument('--num_warmup_steps', type=int, default=0)

==> transformers_lightning-0.7.3.tar.gz: transformers_lightning-0.7.3/transformers_lightning/schedulers/constant_scheduler_with_warmup.py <==
from argparse import ArgumentParser, Namespace

import torch
from pytorch_lightning.utilities.warnings import rank_zero_warn

from transformers_lightning.schedulers.super_scheduler import SuperScheduler


class ConstantSchedulerWithWarmup(SuperScheduler):
    r"""
    Create a schedule with a learning rate that keeps a contant value
    but increases linearly for the first `num_warmup_steps`.
    More informations about the default parameters can be found on the documentation of
    `_LRScheduler` in the `torch` project.

    Args:
        hyperparameters: (:class:`~argparse.Namespace`):
            Collection of training hyperparameters.
        optimizer (:class:`~torch.optim.Optimizer`):
            The optimizer for which to schedule the learning rate.

    Args through CLI:
        num_warmup_steps (:obj:`int`):
            The number of steps for the warmup phase.
        last_epoch (:obj:`int`, `optional`, defaults to -1):
            The index of the last epoch when resuming training.
        verbose (bool): If ``True``, prints a message to stdout for
            each update. Default: ``False``.

    Example:
        >>> scheduler = ConstantSchedulerWithWarmup(hyperparameters, optimizer)
    """

    def __init__(self, hyperparameters: Namespace, optimizer: torch.optim.Optimizer):
        super().__init__(hyperparameters, optimizer)

        if not isinstance(hyperparameters.num_warmup_steps, int) or not hyperparameters.num_warmup_steps >= 0:
            raise ValueError("`num_warmup_steps` must be an integer greater than 0")

    def lr_lambda(self, current_step: int) -> int:
        r""" Compute lambda that is going to scale the learning rate. """
        if current_step < self.hyperparameters.num_warmup_steps:
            return float(current_step) / float(max(1, self.hyperparameters.num_warmup_steps))
        return 1.0

    def get_lr(self):
        if not self._get_lr_called_within_step:
            rank_zero_warn("To get the last learning rate computed by the scheduler, " "please use `get_last_lr()`.")

        return [base_lr * self.lr_lambda(self.last_epoch) for base_lr in self.base_lrs]

    @staticmethod
    def add_scheduler_specific_args(parser: ArgumentParser):
        r""" Add here the hyperparameters specific of the scheduler like the number of warmup steps. """
        super(ConstantSchedulerWithWarmup, ConstantSchedulerWithWarmup).add_scheduler_specific_args(parser)
        parser.add_argument('--num_warmup_steps', type=int, default=0)
